<?php

namespace Drupal\group_flex_content\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class GroupSettingsForm.
 */
class GroupFlexContentSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'group_flex_content_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['group_flex_content.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $config = $this->config('group_flex_content.settings');
    $form['allow_anonymous_content_visibility'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow the group content visibility option "Any visitors of the website" to be used.'),
      '#description' => $this->t('Enables the use of the group content visibility option "Any visitors of the website" to be used with group flex content.'),
      '#default_value' => $config->get('allow_anonymous_content_visibility'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('group_flex_content.settings');
    $allow_anonymous = $config->get('allow_anonymous_content_visibility');
    $allow_anonymous_form = $form_state->getValue('allow_anonymous_content_visibility');

    // Only rebuild the routes if the admin theme switch has changed.
    if ($allow_anonymous !== $allow_anonymous_form) {
      $config->set('allow_anonymous_content_visibility', $allow_anonymous_form)->save();
    }

    parent::submitForm($form, $form_state);
  }

}
